==> cssdk-1.0.02.1-sources.jar: com/css/sdk/cservice/base/http/UrlQuery.java <==
package com.css.sdk.cservice.base.http;

import android.text.TextUtils;

import java.net.URLEncoder;
import java.util.HashMap;
import java.util.Map;

/**
 * UrlQuery
 */
public class UrlQuery {
    private StringBuffer query = new StringBuffer();

    public UrlQuery addParams(Map<String, String> map) {
        if (map != null) {
            for (String key : map.keySet()) {
                if (!TextUtils.isEmpty(key) && map.get(key) != null) {
                    this.add(key, map.get(key));
                }
            }
        }

        return this;
    }

    public UrlQuery addParams(HashMap<String, String> map) {
        if (map != null) {
            for (String key : map.keySet()) {
                if (!TextUtils.isEmpty(key) && map.get(key) != null) {
                    this.add(key, map.get(key));
                }
            }
        }

        return this;
    }

    private UrlQuery add(String key, String value) {
        try {
            if (query.length() > 0) {
                query.append('&');
            }

            if (TextUtils.isEmpty(value)) {
                value = "";
            }
            query.append(URLEncoder.encode(key, "UTF-8")).append('=').append(URLEncoder.encode(value, "UTF-8"));
            //query.append(URLEncoder.encode(key, "UTF-8") + "=" + URLEncoder.encode(value, "UTF-8"));
        } catch (Throwable e) {

        }

        return this;
    }

    public String appendToUrl(String url) {
        return url + (url.contains("?") ? "&" : "?") + toString();
    }

    @Override
    public String toString() {
        return query.toString();
    }
}

==> cssdk-2.0.01.2-sources.jar: com/css/sdk/cservice/base/http/UrlQuery.java <==
package com.css.sdk.cservice.base.http;

import android.text.TextUtils;

import java.net.URLEncoder;
import java.util.HashMap;
import java.util.Map;

/**
 * UrlQuery
 */
public class UrlQuery {
    private StringBuffer query = new StringBuffer();

    public UrlQuery addParams(Map<String, String> map) {
        if (map != null) {
            for(Map.Entry<String,String>  entry : map.entrySet()){
                if (!TextUtils.isEmpty(entry.getKey()) && map.get(entry.getKey()) != null) {
                    this.add(entry.getKey(), map.get(entry.getKey()));
                }
            }

        }
        return this;
    }

    public UrlQuery addParams(HashMap<String, String> map) {
        if (map != null) {
//            for (String key : map.keySet()) {
//                if (!TextUtils.isEmpty(key) && map.get(key) != null) {
//                    this.add(key, map.get(key));
//                }
//            }
            for (Map.Entry<String,String> entry : map.entrySet()) {
                if (!TextUtils.isEmpty(entry.getKey()) && map.get(entry.getKey()) != null) {
                    this.add(entry.getKey(), map.get(entry.getKey()));
                }
            }

        }

        return this;
    }

    private UrlQuery add(String key, String value) {
        try {
            if (query.length() > 0) {
                query.append('&');
            }

            if (TextUtils.isEmpty(value)) {
                value = "";
            }
            query.append(URLEncoder.encode(key, "UTF-8")).append('=').append(URLEncoder.encode(value, "UTF-8"));
            //query.append(URLEncoder.encode(key, "UTF-8") + "=" + URLEncoder.encode(value, "UTF-8"));
        } catch (Throwable e) {

        }

        return this;
    }

    public String appendToUrl(String url) {
        return url + (url.contains("?") ? "&" : "?") + toString();
    }

    @Override
    public String toString() {
        return query.toString();
    }
}
